@@ -16,6 +16,9 @@ Config.define ('gnome/searched', """ List of searchable fields """,
 Config.define ('gnome/history', """ Size of the history file """,
                Config.Integer (min = 1))
 
+Config.define ('gnome/paste-key', """ Paste key instead of entry content """,
+               Config.Boolean ())
+
 # --------------------------------------------------
 
 Config.set ('gnome/searched', ['Author', 'Title', 'Abstract', 'Date'])
@@ -27,3 +30,5 @@ Config.set ('gnome/native-as-default', 0)
 Config.set ('gnome/columns', ('Author', 'Date', 'Title'))
 
 Config.set ('gnome/history', 10)
+
+Config.set ('gnome/paste-key', 1)
