@@ -21,10 +21,9 @@
 
 from Pyblio import Key, Exceptions
 
-import string, types, re, string, recode, urlparse, os, gettext, time
+import string, types, re, string, recode, urlparse, os, time
 
 import copy, re
-_ = gettext.gettext
 
 year_match = re.compile ('(\d\d\d\d)')
 
@@ -155,7 +154,7 @@ class Author:
 
         total = []
 
-        if self.first is None: return None
+        if self.first is None: return ''
         
         for atom in string.split (self.first, ' '):
             list = []
@@ -376,6 +375,23 @@ class Text:
         return ft (self.text)
 
 
+class LongText (Text) :
+    """This subclass of text is used for long texts,
+    i.e. notes and abstracts. """
+
+    def __str__  (self):
+        return self.text
+    
+    def __repr__ (self):
+        return 'LongText (%s)' % `self.text`
+
+    def __len__  (self):
+        return len (self.text)
+
+    def __getitem__ (self, key):
+        return self.text[key]
+    
+   
 class URL:
     ''' Holder for URL data (for example, the location of a database) '''
 
