@@ -1,7 +1,7 @@
 #This file is part of Pybliographer
 # 
 # Copyright (C) 1998-2004 Peter Schulte-Stracke
-# Email : Peter.Schulte-Stracke@t-online.de
+# Email : mail@schulte-stracke.de
 #          
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -198,15 +198,39 @@ class IsifileIterator(Iterator.Iterator):
                 lines['DE'].append ('; ' + val)
             else :
                 lines['DE'] = [val]
-            del lines[key]    
+            del lines[key]
+
+        # journal titles come in various forms
+       
+        if lines.has_key ('SO'):
+            uc_title =  ' '.join(lines['SO'])
+            in_table ['journal'] = uc_title
+            if lines.has_key('JI'):
+                uc_title = re.split(r"([- .,/]+)", uc_title)
+                ca_title = re.split(r"[- .,/]+", ' '.join(lines['JI']))
+                i , Title = 0, []
+                for word in uc_title:
+                    Word = string.capitalize(word)
+                    if word == ca_title [i]:
+                        Title.append (word)
+                        i += 1
+                    elif Word.startswith(ca_title[i]):
+                        Title.append(Word)
+                        i += 1
+                    else:
+                        Title.append(string.lower(word))
+                del lines['JI']
+                in_table['journal'] =  "".join(Title)
+            del lines['SO']
+
+
 
         for key in lines.keys():
-            if key_map.has_key(key):
-                in_table [key_map [key][0]] =  Fields.Text (
-                    string.join (lines[key], key_map[key][1]))
-            else:
-                in_table ['isifile-' + string.lower(key)] = Fields.Text (
-                    string.join (lines[key], " ; "))
+            mapped_key, joiner = key_map.get(
+                key, ('isifile-%s' %(key.lower()), ' ; '))
+            text_type = Types.get_field (mapped_key).type
+            in_table [mapped_key] = text_type (joiner.join(lines[key]))
+
         return Base.Entry ( None, type, in_table)
 
 class Isifile (Base.DataBase):
@@ -269,7 +293,7 @@ def writer (iter, output_stream, preamble=None, postamble = None):
             authors = []
             for author in entry['author']:
                 initials = author.initials()
-                initials = re.sub('\. *','',initials)
+                initials = re.sub('\. *','', initials)
                 authors.append( '%s, %s' % (author.last, initials))
             del remaining ['author']    
             output_write('AU', authors)    
