@@ -39,9 +39,7 @@ from Pyblio import version, Fields, Types, Query
 
 import Pyblio.Style.Utils
 
-import gettext, os, string, copy, types, sys, traceback, stat
-
-_ = gettext.gettext
+import os, string, copy, types, sys, traceback, stat
 
 import cPickle
 
@@ -62,7 +60,10 @@ class Document (Connector.Publisher):
 
         self.w = self.xml.get_widget ('main')
         self.paned = self.xml.get_widget ('main_pane')
-
+        
+        self.w_save_btn = self.xml.get_widget ('_w_save_btn')
+        self.w_save_mnu = self.xml.get_widget ('_w_save_mnu')
+        
         # The Index list
         self.index = Index.Index ()
         self.paned.add1 (self.index.w)
@@ -143,10 +144,8 @@ class Document (Connector.Publisher):
         Fields.run (self.w)
         return
     
-    # remove !
-    def set_entries (self, * arg):
-        from Pyblio.GnomeUI import Fields
-        Fields.run (self.w)
+    def forget_changes_cb (self, * arg):
+        Config.forget_changes()
         return
     
 
@@ -273,6 +272,9 @@ class Document (Connector.Publisher):
         if self.changed:
             text = text + ' ' + _("[modified]")
 
+        self.w_save_btn.set_sensitive (self.changed)
+        self.w_save_mnu.set_sensitive (self.changed)
+
         self.statusbar.set_default (text)
         return
 
@@ -444,7 +446,7 @@ class Document (Connector.Publisher):
     def save_document_as (self, * arg):
         # get a new file name
         (url, how) = FileSelector.URLFileSelection (_("Save As..."),
-                                                    url = False, has_auto = False).run ()
+                                                    url = False, has_auto = False, is_save = True).run ()
         
         if url is None: return
 
@@ -679,7 +681,6 @@ class Document (Connector.Publisher):
 
         elif field == '-type-':
             mode = Sort.TypeSort ()
-
         else:
             mode = Sort.FieldSort (field)
 
@@ -702,8 +703,14 @@ class Document (Connector.Publisher):
     def lyx_cite (self, * arg):
 
         import locale
-        enc = locale.getpreferredencoding ()
 
+        try:
+            enc = locale.getpreferredencoding ()
+
+        except AttributeError:
+            enc = locale.getdefaultlocale()[1]
+
+        
         entries = self.index.selection ()
         if not entries: return
         
@@ -712,7 +719,6 @@ class Document (Connector.Publisher):
 
             try:
                 self.lyx = LyX.LyXClient ()
-
             except IOError, msg:
                 msg = msg [1].decode (enc)
                 self.w.error (_("Can't connect to LyX:\n%s") % msg)
@@ -721,7 +727,6 @@ class Document (Connector.Publisher):
         keys = string.join (map (lambda x: x.key.key, entries), ', ')
         try:
             self.lyx ('citation-insert', keys)
-
         except IOError, msg:
             msg = msg [1].decode (enc)
             self.w.error (_("Can't connect to LyX:\n%s") % msg)
@@ -780,7 +785,7 @@ class Document (Connector.Publisher):
         Utils.config.set_int ('/apps/pybliographic/ui/width',  alloc [2])
         Utils.config.set_int ('/apps/pybliographic/ui/height', alloc [3])
 
-        # 2.- Proportion betzeen list and text
+        # 2.- Proportion between list and text
         height = self.paned.get_position ()
         Utils.config.set_int ('/apps/pybliographic/ui/paned', height)
 
@@ -793,7 +798,7 @@ class Document (Connector.Publisher):
         import gobject
 
         try:
-            gnome.help_display ('pybliographer', '')
+            gnome.help_display ('pybliographer', 'getting-started')
             
         except gobject.GError, msg:
             self.w.error (_("Can't display documentation:\n%s") % msg)
