@@ -21,9 +21,7 @@
 
 ''' Main Module holding all the documents '''
 
-import gettext, copy, os, stat
-
-_ = gettext.gettext
+import copy, os, stat
 
 from Pyblio.GnomeUI import Document, Utils
 from Pyblio import Base, Config
@@ -108,14 +106,15 @@ class Pybliographic:
         
         if not document.close_document_request ():
             return
+
+        if len (self.documents) == 1 and maybe_exit:
+            self.exit_application (self.documents [0])
+            return
         
         document.w.destroy ()
-
         self.documents.remove (document)
         
-        if not self.documents:
-            if maybe_exit: mainquit ()
-            else:          self.new_document ()
+        if not self.documents: self.new_document ()
         return
 
 
@@ -140,6 +139,6 @@ class Pybliographic:
             doc.w.destroy ()
             self.documents.remove (doc)
 
-        mainquit ()
+        main_quit ()
         return
     
